COTEMIG | Colégio e Faculdade / Recuperação de Senha

# Cotemig

Portal COTEMIG - Área Restrita

Recuperação de Senha de Acesso

## Recuperação de Senha

Preencha o formulário abaixo com seu usuário e endereço de e-mail cadastrado no Portal. Caso seja professor ou funcionário, informe também o CPF. Você receberá uma mensagem por e-mail com a nova senha de acesso.

* Usuário:

* E-mail:

CPF (somente professores e funcionários):

Caso não se lembre do endereço de e-mail que cadastrou ou não possua mais acesso a ele, entre em contato com o CAU - Centro de Atendimento ao Usuário pelo endereço atendimento@cotemig.com.br, informando os seguintes dados: usuário (login), nome completo e turma (se aluno).

- ## COTEMIG Barroca

  (31) 3313.6500

  Rua Santa Cruz, 546
  Bairro Barroca
  Belo Horizonte MG
  CEP: 30.431-228

  como chegar

- ## COTEMIG Floresta

  (31) 3236.8400

  Rua Itajubá, 223
  Bairro Floresta
  Belo Horizonte MG
  CEP: 30.150-380

  como chegar

- ## Faculdade COTEMIG

  (31) 3371.3051

  Rua Santa Cruz, 546
  Bairro Barroca
  Belo Horizonte MG
  CEP: 30.431-228

  como chegar

- ## Escritório Central

  (31) 3313.6501

  Rua Litargírio, 25
  Bairro Grajaú
  Belo Horizonte MG
  CEP: 30.431-232

  como chegar